@@ -1,5 +1,5 @@
 import argparse
-import printFibonacci
+from fibonacci_cisco.printFibonacci import getFibonacciCisco
 if __name__ == '__main__':
     parser = argparse.ArgumentParser(
         formatter_class=argparse.ArgumentDefaultsHelpFormatter,
@@ -10,4 +10,4 @@ if __name__ == '__main__':
 
     args= parser.parse_args()
     n = args.index_of_fib
-    printFibonacci.getFibonacciCisco(n)
\ No newline at end of file
+    getFibonacciCisco(n)
\ No newline at end of file
